/****************************************************************************
** Meta object code from reading C++ file 'modemcdma.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.25.0/src/modemcdma.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'modemcdma.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ModemManager9ModemCdmaE_t {};
} // unnamed namespace

template <> constexpr inline auto ModemManager::ModemCdma::qt_create_metaobjectdata<qt_meta_tag_ZN12ModemManager9ModemCdmaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ModemManager::ModemCdma",
        "activationStateChanged",
        "",
        "MMModemCdmaActivationState",
        "state",
        "MMCdmaActivationError",
        "error",
        "QVariantMap",
        "status_changes",
        "meidChanged",
        "meid",
        "esnChanged",
        "esn",
        "sidChanged",
        "sid",
        "nidChanged",
        "nid",
        "cdma1xRegistrationStateChanged",
        "MMModemCdmaRegistrationState",
        "cdma1xRegistrationState",
        "evdoRegistrationStateChanged",
        "evdoRegistrationState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activationStateChanged'
        QtMocHelpers::SignalData<void(MMModemCdmaActivationState, MMCdmaActivationError, const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'meidChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'esnChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'sidChanged'
        QtMocHelpers::SignalData<void(uint)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 },
        }}),
        // Signal 'nidChanged'
        QtMocHelpers::SignalData<void(uint)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 16 },
        }}),
        // Signal 'cdma1xRegistrationStateChanged'
        QtMocHelpers::SignalData<void(MMModemCdmaRegistrationState)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'evdoRegistrationStateChanged'
        QtMocHelpers::SignalData<void(MMModemCdmaRegistrationState)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ModemCdma, qt_meta_tag_ZN12ModemManager9ModemCdmaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ModemManager::ModemCdma::staticMetaObject = { {
    QMetaObject::SuperData::link<Interface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager9ModemCdmaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager9ModemCdmaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ModemManager9ModemCdmaE_t>.metaTypes,
    nullptr
} };

void ModemManager::ModemCdma::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ModemCdma *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activationStateChanged((*reinterpret_cast<std::add_pointer_t<MMModemCdmaActivationState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MMCdmaActivationError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 1: _t->meidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->esnChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->sidChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: _t->nidChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 5: _t->cdma1xRegistrationStateChanged((*reinterpret_cast<std::add_pointer_t<MMModemCdmaRegistrationState>>(_a[1]))); break;
        case 6: _t->evdoRegistrationStateChanged((*reinterpret_cast<std::add_pointer_t<MMModemCdmaRegistrationState>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMCdmaActivationError >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMModemCdmaActivationState >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMModemCdmaRegistrationState >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMModemCdmaRegistrationState >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ModemCdma::*)(MMModemCdmaActivationState , MMCdmaActivationError , const QVariantMap & )>(_a, &ModemCdma::activationStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemCdma::*)(const QString & )>(_a, &ModemCdma::meidChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemCdma::*)(const QString & )>(_a, &ModemCdma::esnChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemCdma::*)(uint )>(_a, &ModemCdma::sidChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemCdma::*)(uint )>(_a, &ModemCdma::nidChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemCdma::*)(MMModemCdmaRegistrationState )>(_a, &ModemCdma::cdma1xRegistrationStateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemCdma::*)(MMModemCdmaRegistrationState )>(_a, &ModemCdma::evdoRegistrationStateChanged, 6))
            return;
    }
}

const QMetaObject *ModemManager::ModemCdma::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModemManager::ModemCdma::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager9ModemCdmaE_t>.strings))
        return static_cast<void*>(this);
    return Interface::qt_metacast(_clname);
}

int ModemManager::ModemCdma::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Interface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ModemManager::ModemCdma::activationStateChanged(MMModemCdmaActivationState _t1, MMCdmaActivationError _t2, const QVariantMap & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void ModemManager::ModemCdma::meidChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ModemManager::ModemCdma::esnChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ModemManager::ModemCdma::sidChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ModemManager::ModemCdma::nidChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ModemManager::ModemCdma::cdma1xRegistrationStateChanged(MMModemCdmaRegistrationState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ModemManager::ModemCdma::evdoRegistrationStateChanged(MMModemCdmaRegistrationState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
