/****************************************************************************
** Meta object code from reading C++ file 'modeminterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.25.0/src/dbus/modeminterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'modeminterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN41OrgFreedesktopModemManager1ModemInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1ModemInterface::qt_create_metaobjectdata<qt_meta_tag_ZN41OrgFreedesktopModemManager1ModemInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1ModemInterface",
        "StateChanged",
        "",
        "oldState",
        "newState",
        "reason",
        "Command",
        "QDBusPendingReply<QString>",
        "cmd",
        "timeout",
        "CreateBearer",
        "QDBusPendingReply<QDBusObjectPath>",
        "QVariantMap",
        "properties",
        "DeleteBearer",
        "QDBusPendingReply<>",
        "QDBusObjectPath",
        "bearer",
        "Enable",
        "enable",
        "FactoryReset",
        "code",
        "GetCellInfo",
        "QDBusPendingReply<ModemManager::QVariantMapList>",
        "ListBearers",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "Reset",
        "SetCurrentBands",
        "QList<uint>",
        "bands",
        "SetCurrentCapabilities",
        "capabilities",
        "SetCurrentModes",
        "ModemManager::CurrentModesType",
        "modes",
        "SetPrimarySimSlot",
        "slot",
        "SetPowerState",
        "state",
        "AccessTechnologies",
        "Bearers",
        "QList<QDBusObjectPath>",
        "CarrierConfiguration",
        "CarrierConfigurationRevision",
        "CurrentBands",
        "ModemManager::UIntList",
        "CurrentCapabilities",
        "CurrentModes",
        "Device",
        "DeviceIdentifier",
        "Drivers",
        "EquipmentIdentifier",
        "HardwareRevision",
        "Manufacturer",
        "MaxActiveBearers",
        "MaxActiveMultiplexedBearers",
        "MaxBearers",
        "Model",
        "OwnNumbers",
        "Plugin",
        "Ports",
        "ModemManager::PortList",
        "PowerState",
        "PrimaryPort",
        "PrimarySimSlot",
        "Physdev",
        "Revision",
        "SignalQuality",
        "ModemManager::SignalQualityPair",
        "Sim",
        "SimSlots",
        "State",
        "StateFailedReason",
        "SupportedBands",
        "SupportedCapabilities",
        "SupportedIpFamilies",
        "SupportedModes",
        "ModemManager::SupportedModesType",
        "UnlockRequired",
        "UnlockRetries",
        "ModemManager::UnlockRetriesMap"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'StateChanged'
        QtMocHelpers::SignalData<void(int, int, uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::UInt, 5 },
        }}),
        // Slot 'Command'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, uint)>(6, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 8 }, { QMetaType::UInt, 9 },
        }}),
        // Slot 'CreateBearer'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QVariantMap &)>(10, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'DeleteBearer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(14, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'Enable'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(18, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'FactoryReset'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'GetCellInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<ModemManager::QVariantMapList>()>(22, 2, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'ListBearers'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath>>()>(24, 2, QMC::AccessPublic, 0x80000000 | 25),
        // Slot 'Reset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(26, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'SetCurrentBands'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QList<uint> &)>(27, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'SetCurrentCapabilities'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(30, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::UInt, 31 },
        }}),
        // Slot 'SetCurrentModes'
        QtMocHelpers::SlotData<QDBusPendingReply<>(ModemManager::CurrentModesType)>(32, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'SetPrimarySimSlot'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(35, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::UInt, 36 },
        }}),
        // Slot 'SetPowerState'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(37, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::UInt, 38 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'AccessTechnologies'
        QtMocHelpers::PropertyData<uint>(39, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Bearers'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'CarrierConfiguration'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'CarrierConfigurationRevision'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'CurrentBands'
        QtMocHelpers::PropertyData<ModemManager::UIntList>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'CurrentCapabilities'
        QtMocHelpers::PropertyData<uint>(46, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'CurrentModes'
        QtMocHelpers::PropertyData<ModemManager::CurrentModesType>(47, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Device'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'DeviceIdentifier'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Drivers'
        QtMocHelpers::PropertyData<QStringList>(50, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'EquipmentIdentifier'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HardwareRevision'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Manufacturer'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'MaxActiveBearers'
        QtMocHelpers::PropertyData<uint>(54, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'MaxActiveMultiplexedBearers'
        QtMocHelpers::PropertyData<uint>(55, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'MaxBearers'
        QtMocHelpers::PropertyData<uint>(56, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Model'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'OwnNumbers'
        QtMocHelpers::PropertyData<QStringList>(58, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'Plugin'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Ports'
        QtMocHelpers::PropertyData<ModemManager::PortList>(60, 0x80000000 | 61, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'PowerState'
        QtMocHelpers::PropertyData<uint>(62, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'PrimaryPort'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'PrimarySimSlot'
        QtMocHelpers::PropertyData<uint>(64, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Physdev'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Revision'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SignalQuality'
        QtMocHelpers::PropertyData<ModemManager::SignalQualityPair>(67, 0x80000000 | 68, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Sim'
        QtMocHelpers::PropertyData<QDBusObjectPath>(69, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'SimSlots'
        QtMocHelpers::PropertyData<ModemManager::UIntList>(70, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'State'
        QtMocHelpers::PropertyData<int>(71, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'StateFailedReason'
        QtMocHelpers::PropertyData<uint>(72, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'SupportedBands'
        QtMocHelpers::PropertyData<ModemManager::UIntList>(73, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'SupportedCapabilities'
        QtMocHelpers::PropertyData<ModemManager::UIntList>(74, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'SupportedIpFamilies'
        QtMocHelpers::PropertyData<uint>(75, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'SupportedModes'
        QtMocHelpers::PropertyData<ModemManager::SupportedModesType>(76, 0x80000000 | 77, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'UnlockRequired'
        QtMocHelpers::PropertyData<uint>(78, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'UnlockRetries'
        QtMocHelpers::PropertyData<ModemManager::UnlockRetriesMap>(79, 0x80000000 | 80, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1ModemInterface, qt_meta_tag_ZN41OrgFreedesktopModemManager1ModemInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1ModemInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN41OrgFreedesktopModemManager1ModemInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN41OrgFreedesktopModemManager1ModemInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN41OrgFreedesktopModemManager1ModemInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1ModemInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1ModemInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->StateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 1: { QDBusPendingReply<QString> _r = _t->Command((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreateBearer((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->DeleteBearer((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->Enable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->FactoryReset((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<ModemManager::QVariantMapList> _r = _t->GetCellInfo();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<ModemManager::QVariantMapList>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->ListBearers();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->SetCurrentBands((*reinterpret_cast<std::add_pointer_t<QList<uint>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->SetCurrentCapabilities((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->SetCurrentModes((*reinterpret_cast<std::add_pointer_t<ModemManager::CurrentModesType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->SetPrimarySimSlot((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->SetPowerState((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<uint> >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::CurrentModesType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopModemManager1ModemInterface::*)(int , int , uint )>(_a, &OrgFreedesktopModemManager1ModemInterface::StateChanged, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::CurrentModesType >(); break;
        case 19:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::PortList >(); break;
        case 25:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::SignalQualityPair >(); break;
        case 33:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::SupportedModesType >(); break;
        case 31:
        case 30:
        case 27:
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::UIntList >(); break;
        case 35:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::UnlockRetriesMap >(); break;
        case 26:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->accessTechnologies(); break;
        case 1: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->bearers(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->carrierConfiguration(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->carrierConfigurationRevision(); break;
        case 4: *reinterpret_cast<ModemManager::UIntList*>(_v) = _t->currentBands(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->currentCapabilities(); break;
        case 6: *reinterpret_cast<ModemManager::CurrentModesType*>(_v) = _t->currentModes(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->device(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->deviceIdentifier(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->drivers(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->equipmentIdentifier(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->hardwareRevision(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->manufacturer(); break;
        case 13: *reinterpret_cast<uint*>(_v) = _t->maxActiveBearers(); break;
        case 14: *reinterpret_cast<uint*>(_v) = _t->maxActiveMultiplexedBearers(); break;
        case 15: *reinterpret_cast<uint*>(_v) = _t->maxBearers(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->ownNumbers(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->plugin(); break;
        case 19: *reinterpret_cast<ModemManager::PortList*>(_v) = _t->ports(); break;
        case 20: *reinterpret_cast<uint*>(_v) = _t->powerState(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->primaryPort(); break;
        case 22: *reinterpret_cast<uint*>(_v) = _t->primarySimSlot(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->physdev(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->revision(); break;
        case 25: *reinterpret_cast<ModemManager::SignalQualityPair*>(_v) = _t->signalQuality(); break;
        case 26: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->sim(); break;
        case 27: *reinterpret_cast<ModemManager::UIntList*>(_v) = _t->simSlots(); break;
        case 28: *reinterpret_cast<int*>(_v) = _t->state(); break;
        case 29: *reinterpret_cast<uint*>(_v) = _t->stateFailedReason(); break;
        case 30: *reinterpret_cast<ModemManager::UIntList*>(_v) = _t->supportedBands(); break;
        case 31: *reinterpret_cast<ModemManager::UIntList*>(_v) = _t->supportedCapabilities(); break;
        case 32: *reinterpret_cast<uint*>(_v) = _t->supportedIpFamilies(); break;
        case 33: *reinterpret_cast<ModemManager::SupportedModesType*>(_v) = _t->supportedModes(); break;
        case 34: *reinterpret_cast<uint*>(_v) = _t->unlockRequired(); break;
        case 35: *reinterpret_cast<ModemManager::UnlockRetriesMap*>(_v) = _t->unlockRetries(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1ModemInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1ModemInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN41OrgFreedesktopModemManager1ModemInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1ModemInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopModemManager1ModemInterface::StateChanged(int _t1, int _t2, uint _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
