/****************************************************************************
** Meta object code from reading C++ file 'bearer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.25.0/src/bearer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bearer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ModemManager6BearerE_t {};
} // unnamed namespace

template <> constexpr inline auto ModemManager::Bearer::qt_create_metaobjectdata<qt_meta_tag_ZN12ModemManager6BearerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ModemManager::Bearer",
        "interfaceChanged",
        "",
        "iface",
        "connectedChanged",
        "connected",
        "connectionErrorChanged",
        "ModemManager::ConnectionError",
        "error",
        "suspendedChanged",
        "suspended",
        "multiplexedChanged",
        "multiplexed",
        "ip4ConfigChanged",
        "ModemManager::IpConfig",
        "ipv4Config",
        "ip6ConfigChanged",
        "ipv6Config",
        "ipTimeoutChanged",
        "ipTimeout",
        "bearerTypeChanged",
        "MMBearerType",
        "bearerType",
        "profileIdChanged",
        "profileId",
        "reloadStatsSupportedChanged",
        "supported",
        "statsChanged",
        "QVariantMap",
        "stats",
        "propertiesChanged",
        "properties"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'interfaceChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'connectedChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'connectionErrorChanged'
        QtMocHelpers::SignalData<void(const ModemManager::ConnectionError &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'suspendedChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'multiplexedChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'ip4ConfigChanged'
        QtMocHelpers::SignalData<void(const ModemManager::IpConfig &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'ip6ConfigChanged'
        QtMocHelpers::SignalData<void(const ModemManager::IpConfig &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 17 },
        }}),
        // Signal 'ipTimeoutChanged'
        QtMocHelpers::SignalData<void(uint)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 19 },
        }}),
        // Signal 'bearerTypeChanged'
        QtMocHelpers::SignalData<void(MMBearerType)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'profileIdChanged'
        QtMocHelpers::SignalData<void(uint)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 24 },
        }}),
        // Signal 'reloadStatsSupportedChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Signal 'statsChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Signal 'propertiesChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Bearer, qt_meta_tag_ZN12ModemManager6BearerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ModemManager::Bearer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager6BearerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager6BearerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ModemManager6BearerE_t>.metaTypes,
    nullptr
} };

void ModemManager::Bearer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Bearer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->interfaceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->connectedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->connectionErrorChanged((*reinterpret_cast<std::add_pointer_t<ModemManager::ConnectionError>>(_a[1]))); break;
        case 3: _t->suspendedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->multiplexedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->ip4ConfigChanged((*reinterpret_cast<std::add_pointer_t<ModemManager::IpConfig>>(_a[1]))); break;
        case 6: _t->ip6ConfigChanged((*reinterpret_cast<std::add_pointer_t<ModemManager::IpConfig>>(_a[1]))); break;
        case 7: _t->ipTimeoutChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: _t->bearerTypeChanged((*reinterpret_cast<std::add_pointer_t<MMBearerType>>(_a[1]))); break;
        case 9: _t->profileIdChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 10: _t->reloadStatsSupportedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->statsChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 12: _t->propertiesChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::ConnectionError >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::IpConfig >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::IpConfig >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMBearerType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(const QString & )>(_a, &Bearer::interfaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(bool )>(_a, &Bearer::connectedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(const ModemManager::ConnectionError & )>(_a, &Bearer::connectionErrorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(bool )>(_a, &Bearer::suspendedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(bool )>(_a, &Bearer::multiplexedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(const ModemManager::IpConfig & )>(_a, &Bearer::ip4ConfigChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(const ModemManager::IpConfig & )>(_a, &Bearer::ip6ConfigChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(uint )>(_a, &Bearer::ipTimeoutChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(MMBearerType )>(_a, &Bearer::bearerTypeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(uint )>(_a, &Bearer::profileIdChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(bool )>(_a, &Bearer::reloadStatsSupportedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(const QVariantMap & )>(_a, &Bearer::statsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bearer::*)(const QVariantMap & )>(_a, &Bearer::propertiesChanged, 12))
            return;
    }
}

const QMetaObject *ModemManager::Bearer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModemManager::Bearer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager6BearerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ModemManager::Bearer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ModemManager::Bearer::interfaceChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ModemManager::Bearer::connectedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ModemManager::Bearer::connectionErrorChanged(const ModemManager::ConnectionError & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ModemManager::Bearer::suspendedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ModemManager::Bearer::multiplexedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ModemManager::Bearer::ip4ConfigChanged(const ModemManager::IpConfig & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ModemManager::Bearer::ip6ConfigChanged(const ModemManager::IpConfig & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ModemManager::Bearer::ipTimeoutChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ModemManager::Bearer::bearerTypeChanged(MMBearerType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ModemManager::Bearer::profileIdChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ModemManager::Bearer::reloadStatsSupportedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void ModemManager::Bearer::statsChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ModemManager::Bearer::propertiesChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
