/****************************************************************************
** Meta object code from reading C++ file 'locationinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.25.0/src/dbus/locationinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'locationinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN49OrgFreedesktopModemManager1ModemLocationInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1ModemLocationInterface::qt_create_metaobjectdata<qt_meta_tag_ZN49OrgFreedesktopModemManager1ModemLocationInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1ModemLocationInterface",
        "InjectAssistanceData",
        "QDBusPendingReply<>",
        "",
        "data",
        "GetLocation",
        "QDBusPendingReply<ModemManager::LocationInformationMap>",
        "SetGpsRefreshRate",
        "rate",
        "SetSuplServer",
        "server",
        "Setup",
        "sources",
        "signal_location",
        "Capabilities",
        "Enabled",
        "SupportedAssistanceData",
        "SuplServer",
        "AssistanceDataServers",
        "GpsRefreshRate",
        "Location",
        "ModemManager::LocationInformationMap",
        "SignalsLocation"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'InjectAssistanceData'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QByteArray &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QByteArray, 4 },
        }}),
        // Slot 'GetLocation'
        QtMocHelpers::SlotData<QDBusPendingReply<ModemManager::LocationInformationMap>()>(5, 3, QMC::AccessPublic, 0x80000000 | 6),
        // Slot 'SetGpsRefreshRate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(7, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 8 },
        }}),
        // Slot 'SetSuplServer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(9, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'Setup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, bool)>(11, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 12 }, { QMetaType::Bool, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Capabilities'
        QtMocHelpers::PropertyData<uint>(14, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Enabled'
        QtMocHelpers::PropertyData<uint>(15, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'SupportedAssistanceData'
        QtMocHelpers::PropertyData<uint>(16, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'SuplServer'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'AssistanceDataServers'
        QtMocHelpers::PropertyData<QStringList>(18, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'GpsRefreshRate'
        QtMocHelpers::PropertyData<uint>(19, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Location'
        QtMocHelpers::PropertyData<ModemManager::LocationInformationMap>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'SignalsLocation'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1ModemLocationInterface, qt_meta_tag_ZN49OrgFreedesktopModemManager1ModemLocationInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1ModemLocationInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN49OrgFreedesktopModemManager1ModemLocationInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN49OrgFreedesktopModemManager1ModemLocationInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN49OrgFreedesktopModemManager1ModemLocationInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1ModemLocationInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1ModemLocationInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->InjectAssistanceData((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<ModemManager::LocationInformationMap> _r = _t->GetLocation();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<ModemManager::LocationInformationMap>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->SetGpsRefreshRate((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->SetSuplServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->Setup((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::LocationInformationMap >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->capabilities(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->enabled(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->supportedAssistanceData(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->suplServer(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->assistanceDataServers(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->gpsRefreshRate(); break;
        case 6: *reinterpret_cast<ModemManager::LocationInformationMap*>(_v) = _t->location(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->signalsLocation(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1ModemLocationInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1ModemLocationInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN49OrgFreedesktopModemManager1ModemLocationInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1ModemLocationInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
