/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -i generictypes.h -p voiceinterface ./introspection/org.freedesktop.ModemManager1.Modem.Voice.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef VOICEINTERFACE_H
#define VOICEINTERFACE_H

#include "generictypes.h"
#include <QDBusAbstractInterface>
#include <QDBusPendingReply>
#include <QList>
#include <QObject>
#include <QString>
#include <QVariant>

/*
 * Proxy class for interface org.freedesktop.ModemManager1.Modem.Voice
 */
class OrgFreedesktopModemManager1ModemVoiceInterface : public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    {
        return "org.freedesktop.ModemManager1.Modem.Voice";
    }

public:
    OrgFreedesktopModemManager1ModemVoiceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopModemManager1ModemVoiceInterface() override;

    Q_PROPERTY(QList<QDBusObjectPath> Calls READ calls)
    inline QList<QDBusObjectPath> calls() const
    {
        return qvariant_cast<QList<QDBusObjectPath>>(property("Calls"));
    }

    Q_PROPERTY(bool EmergencyOnly READ emergencyOnly)
    inline bool emergencyOnly() const
    {
        return qvariant_cast<bool>(property("EmergencyOnly"));
    }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QDBusObjectPath> CreateCall(const QVariantMap &properties)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(properties);
        return asyncCallWithArgumentList(QStringLiteral("CreateCall"), argumentList);
    }

    inline QDBusPendingReply<> DeleteCall(const QDBusObjectPath &path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(path);
        return asyncCallWithArgumentList(QStringLiteral("DeleteCall"), argumentList);
    }

    inline QDBusPendingReply<> HoldAndAccept()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("HoldAndAccept"), argumentList);
    }

    inline QDBusPendingReply<> HangupAndAccept()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("HangupAndAccept"), argumentList);
    }

    inline QDBusPendingReply<> HangupAll()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("HangupAll"), argumentList);
    }

    inline QDBusPendingReply<> Transfer()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Transfer"), argumentList);
    }

    inline QDBusPendingReply<> CallWaitingSetup(bool enabled)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(enabled);
        return asyncCallWithArgumentList(QStringLiteral("CallWaitingSetup"), argumentList);
    }

    inline QDBusPendingReply<bool> CallWaitingQuery()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("CallWaitingQuery"), argumentList);
    }

    inline QDBusPendingReply<QList<QDBusObjectPath>> ListCalls()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ListCalls"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void CallAdded(const QDBusObjectPath &path);
    void CallDeleted(const QDBusObjectPath &path);
};

#endif
