/****************************************************************************
** Meta object code from reading C++ file 'modemsignal.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.25.0/src/modemsignal.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'modemsignal.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ModemManager11ModemSignalE_t {};
} // unnamed namespace

template <> constexpr inline auto ModemManager::ModemSignal::qt_create_metaobjectdata<qt_meta_tag_ZN12ModemManager11ModemSignalE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ModemManager::ModemSignal",
        "rateChanged",
        "",
        "rate",
        "rssiThresholdChanged",
        "threshold",
        "errorRateThresholdChanged",
        "enabled",
        "cdmaChanged",
        "QVariantMap",
        "cdma",
        "evdoChanged",
        "evdo",
        "gsmChanged",
        "gsm",
        "umtsChanged",
        "umts",
        "lteChanged",
        "lte",
        "nr5gChanged",
        "nr5g"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rateChanged'
        QtMocHelpers::SignalData<void(uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'rssiThresholdChanged'
        QtMocHelpers::SignalData<void(uint)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Signal 'errorRateThresholdChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'cdmaChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'evdoChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Signal 'gsmChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 14 },
        }}),
        // Signal 'umtsChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 16 },
        }}),
        // Signal 'lteChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 18 },
        }}),
        // Signal 'nr5gChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ModemSignal, qt_meta_tag_ZN12ModemManager11ModemSignalE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ModemManager::ModemSignal::staticMetaObject = { {
    QMetaObject::SuperData::link<Interface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager11ModemSignalE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager11ModemSignalE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ModemManager11ModemSignalE_t>.metaTypes,
    nullptr
} };

void ModemManager::ModemSignal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ModemSignal *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rateChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: _t->rssiThresholdChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 2: _t->errorRateThresholdChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->cdmaChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 4: _t->evdoChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 5: _t->gsmChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 6: _t->umtsChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 7: _t->lteChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 8: _t->nr5gChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ModemSignal::*)(uint )>(_a, &ModemSignal::rateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemSignal::*)(uint )>(_a, &ModemSignal::rssiThresholdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemSignal::*)(bool )>(_a, &ModemSignal::errorRateThresholdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemSignal::*)(const QVariantMap & )>(_a, &ModemSignal::cdmaChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemSignal::*)(const QVariantMap & )>(_a, &ModemSignal::evdoChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemSignal::*)(const QVariantMap & )>(_a, &ModemSignal::gsmChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemSignal::*)(const QVariantMap & )>(_a, &ModemSignal::umtsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemSignal::*)(const QVariantMap & )>(_a, &ModemSignal::lteChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemSignal::*)(const QVariantMap & )>(_a, &ModemSignal::nr5gChanged, 8))
            return;
    }
}

const QMetaObject *ModemManager::ModemSignal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModemManager::ModemSignal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager11ModemSignalE_t>.strings))
        return static_cast<void*>(this);
    return Interface::qt_metacast(_clname);
}

int ModemManager::ModemSignal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Interface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ModemManager::ModemSignal::rateChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ModemManager::ModemSignal::rssiThresholdChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ModemManager::ModemSignal::errorRateThresholdChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ModemManager::ModemSignal::cdmaChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ModemManager::ModemSignal::evdoChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ModemManager::ModemSignal::gsmChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ModemManager::ModemSignal::umtsChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ModemManager::ModemSignal::lteChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ModemManager::ModemSignal::nr5gChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
