/****************************************************************************
** Meta object code from reading C++ file 'voiceinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.25.0/src/dbus/voiceinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'voiceinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN46OrgFreedesktopModemManager1ModemVoiceInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1ModemVoiceInterface::qt_create_metaobjectdata<qt_meta_tag_ZN46OrgFreedesktopModemManager1ModemVoiceInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1ModemVoiceInterface",
        "CallAdded",
        "",
        "QDBusObjectPath",
        "path",
        "CallDeleted",
        "CreateCall",
        "QDBusPendingReply<QDBusObjectPath>",
        "QVariantMap",
        "properties",
        "DeleteCall",
        "QDBusPendingReply<>",
        "HoldAndAccept",
        "HangupAndAccept",
        "HangupAll",
        "Transfer",
        "CallWaitingSetup",
        "enabled",
        "CallWaitingQuery",
        "QDBusPendingReply<bool>",
        "ListCalls",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "Calls",
        "QList<QDBusObjectPath>",
        "EmergencyOnly"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CallAdded'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'CallDeleted'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'CreateCall'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QVariantMap &)>(6, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'DeleteCall'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(10, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'HoldAndAccept'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(12, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'HangupAndAccept'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(13, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'HangupAll'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(14, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'Transfer'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(15, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'CallWaitingSetup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(16, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'CallWaitingQuery'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
        // Slot 'ListCalls'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath>>()>(20, 2, QMC::AccessPublic, 0x80000000 | 21),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Calls'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'EmergencyOnly'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1ModemVoiceInterface, qt_meta_tag_ZN46OrgFreedesktopModemManager1ModemVoiceInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1ModemVoiceInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46OrgFreedesktopModemManager1ModemVoiceInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46OrgFreedesktopModemManager1ModemVoiceInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN46OrgFreedesktopModemManager1ModemVoiceInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1ModemVoiceInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1ModemVoiceInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CallAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 1: _t->CallDeleted((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 2: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreateCall((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->DeleteCall((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->HoldAndAccept();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->HangupAndAccept();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->HangupAll();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->Transfer();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->CallWaitingSetup((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<bool> _r = _t->CallWaitingQuery();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->ListCalls();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopModemManager1ModemVoiceInterface::*)(const QDBusObjectPath & )>(_a, &OrgFreedesktopModemManager1ModemVoiceInterface::CallAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopModemManager1ModemVoiceInterface::*)(const QDBusObjectPath & )>(_a, &OrgFreedesktopModemManager1ModemVoiceInterface::CallDeleted, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->calls(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->emergencyOnly(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1ModemVoiceInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1ModemVoiceInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46OrgFreedesktopModemManager1ModemVoiceInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1ModemVoiceInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopModemManager1ModemVoiceInterface::CallAdded(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgFreedesktopModemManager1ModemVoiceInterface::CallDeleted(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
