/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -i ../generictypes.h -p siminterface
 * /home/devin/kde/src/modemmanager-qt/src/dbus/introspection/org.freedesktop.ModemManager1.Modem.CellBroadcast.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "cellbroadcastinterface.h"

/*
 * Implementation of interface class OrgFreedesktopModemManager1ModemCellBroadcastInterface
 */

OrgFreedesktopModemManager1ModemCellBroadcastInterface::OrgFreedesktopModemManager1ModemCellBroadcastInterface(const QString &service,
                                                                                                               const QString &path,
                                                                                                               const QDBusConnection &connection,
                                                                                                               QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopModemManager1ModemCellBroadcastInterface::~OrgFreedesktopModemManager1ModemCellBroadcastInterface()
{
}

#include "moc_cellbroadcastinterface.cpp"
